@@ -1,5 +1,5 @@
 #
-# $Id: Consts.pm 1640 2009-11-09 17:58:27Z gomor $
+# $Id: Consts.pm 2002 2015-02-15 16:50:35Z gomor $
 #
 package Net::Packet::Consts;
 use strict;
@@ -368,8 +368,8 @@ use constant NP_PPP_PROTOCOL_IPv4   => 0x0021;
 use constant NP_PPP_PROTOCOL_PPPLCP => 0xc021;
 
 use constant NP_PPPoE_HDR_LEN => 8;
-use constant NP_PPPoE_PPP_PROTOCOL_IPv4   => NP_PPP_PROTOCOL_IPv4;
-use constant NP_PPPoE_PPP_PROTOCOL_PPPLCP => NP_PPP_PROTOCOL_PPPLCP;
+use constant NP_PPPoE_PPP_PROTOCOL_IPv4   => NP_PPP_PROTOCOL_IPv4();
+use constant NP_PPPoE_PPP_PROTOCOL_PPPLCP => NP_PPP_PROTOCOL_PPPLCP();
 
 use constant NP_LLC_HDR_LEN   => 8;
 use constant NP_LLC_OUI_CISCO => 0x00000c;
@@ -482,10 +482,10 @@ Net::Packet::Consts - all constants used in Net::Packet framework
    # Load IPv4 layer constants
    use Net::Packet::Consts qw(:ipv4);
 
-   #Load Ethernet layer constants
+   # Load Ethernet layer constants
    use Net::Packet::Consts qw(:eth);
 
-   #Load Ethernet, IPv6 and TCP layers constants
+   # Load Ethernet, IPv6 and TCP layers constants
    use Net::Packet::Consts qw(:eth :ipv6 :tcp);
 
 =head1 DESCRIPTION
@@ -498,7 +498,7 @@ Patrice E<lt>GomoRE<gt> Auffret
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2004-2009, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2004-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of the Artistic license.
 See LICENSE.Artistic file in the source distribution archive.
